@@ -256,16 +256,18 @@ subroutine getinp()
 
    ! Checking for the name of the output file to be created
 
-   xyzout = '####'
-   do iline = 1, nlines
-      if(keyword(iline,1).eq.'output') then
-         xyzout = keyword(iline,2)
-         xyzout = trim(adjustl(xyzout))
+   if (len(trim(xyzout)) == 0) then
+      xyzout = '####'
+      do iline = 1, nlines
+         if(keyword(iline,1).eq.'output') then
+            xyzout = keyword(iline,2)
+            xyzout = trim(adjustl(xyzout))
+         end if
+      end do
+      if(xyzout(1:4) == '####') then
+         write(*,*)' ERROR: Output file not (correctly?) specified. '
+         stop exit_code_input_error
       end if
-   end do
-   if(xyzout(1:4) == '####') then
-      write(*,*)' ERROR: Output file not (correctly?) specified. '
-      stop exit_code_input_error
    end if
    write(*,*)' Output file: ', trim(adjustl(xyzout))
 
@@ -773,8 +775,13 @@ subroutine getinp()
       end if
    end do
 
-   ! Assigning the input lines that correspond to each structure
 
+   ! Default to all non-fixed molecules may be moved.
+   do itype = 1, ntype
+     maxmove(itype) = nmols(itype)
+   end do
+
+   ! Assigning the input lines that correspond to each structure
    itype = 0
    iline = 0
    do while(iline < nlines)
@@ -785,6 +792,9 @@ subroutine getinp()
          iline = iline + 1
          do while(keyword(iline,1).ne.'end'.or.&
             keyword(iline,2).ne.'structure')
+            if(keyword(iline,1).eq.'maxmove') then
+               read(keyword(iline,2),*) maxmove(itype)
+            end if
             if(keyword(iline,1) == 'structure'.or.&
                iline == nlines) then
                write(*,*) ' ERROR: Structure specification not ending with "end structure"'
@@ -806,16 +816,12 @@ subroutine getinp()
          changechains(itype) = .false.
          chain(itype) = "#"
          segid(itype) = ""
-         maxmove(itype) = nmols(itype)
          do iline = 1, nlines
             if(iline.gt.linestrut(itype,1).and.&
                iline.lt.linestrut(itype,2)) then
                if(keyword(iline,1).eq.'changechains') then
                   changechains(itype) = .true.
                end if
-               if(keyword(iline,1).eq.'maxmove') then
-                  read(keyword(iline,2),*) maxmove(itype)
-               end if
                if(keyword(iline,1).eq.'resnumbers') then
                   read(keyword(iline,2),*) resnumbers(itype)
                end if
